// java wrapper for vtkImageToStructuredPoints object
//

package vtk;
import vtk.*;

public class vtkImageToStructuredPoints extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetVectorInputData_2(vtkImageData id0);
  public void SetVectorInputData(vtkImageData id0)
    { SetVectorInputData_2(id0); }

  private native long GetVectorInput_3();
  public vtkImageData GetVectorInput() {
    long temp = GetVectorInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_4();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_4();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkImageToStructuredPoints() { super(); }

  public vtkImageToStructuredPoints(long id) { super(id); }
  public native long   VTKInit();

}
